@@ -17,7 +17,11 @@ from django.template import InvalidTemplateLibrary
 from django.template.context import BaseContext
 from django.template.loaders import app_directories
 from django.utils.importlib import import_module
-from django.utils import six
+
+try:
+    from django.utils import six
+except ImportError:
+    import six
 
 from . import builtins, utils
 from .library import Library
